@@ -4,7 +4,9 @@ use warnings;
 use base qw/Exporter/;
 use File::Spec;
 use FindBin;
-use lib File::Spec->catfile($FindBin::Bin, '..', 'lib');
+use File::Basename;
+use File::Spec;
+use lib File::Spec->rel2abs(File::Spec->catfile(dirname(__FILE__), '..', 'lib'));
 use Test::More;
 use App::Prove;
 use File::Basename;
